@@ -19,12 +19,12 @@
 
 ;;; Code:
 
+(defconst bbdb-version "3.1.2" "Version of BBDB.")
+
 (if (< emacs-major-version 23)
-  (error "BBDB requires GNU Emacs 23 or later"))
+  (error "BBDB %s requires GNU Emacs 23 or later" bbdb-version))
 
-(defconst bbdb-version "3.1.1" "Version of BBDB.")
-
-(defconst bbdb-version-date "2014-03-11 18:16:12-05:00"
+(defconst bbdb-version-date "2014-04-27 15:07:24-05:00"
   "Version date of BBDB.")
 
 (defcustom bbdb-print-tex-path '("/usr/local/share/bbdb")
